pub struct WidgetData { /* private fields */ }Expand description
Request descriptor for Gingr reservation widget data at a provider timestamp.
Implementations
Sourceimpl WidgetData
impl WidgetData
Sourcepub fn builder() -> WidgetDataBuilder
pub fn builder() -> WidgetDataBuilder
Starts a builder that makes each provider parameter explicit before request capture.